@@ -29,7 +29,7 @@ class I18nBackendFallbacksTranslateTest < I18n::TestCase
   end
 
   test "keeps the count option when defaulting to a different key" do
-    assert_equal 'Interpolate 5 10', I18n.t(:non_existant, default: :interpolate_count, count: 10, value: 5)
+    assert_equal 'Interpolate 5 10', I18n.t(:non_existent, default: :interpolate_count, count: 10, value: 5)
   end
 
   test "returns the :de translation for a missing :'de-DE' when :default is a String" do
@@ -60,8 +60,18 @@ class I18nBackendFallbacksTranslateTest < I18n::TestCase
     assert_nil I18n.t(:missing_bar, :locale => :'de-DE', :default => nil)
   end
 
-  test "returns the translation missing message if the default is also missing" do
-    assert_equal 'translation missing: de-DE.missing_bar', I18n.t(:missing_bar, :locale => :'de-DE', :default => [:missing_baz])
+  test "returns the Translation missing: message if the default is also missing" do
+    translation_missing_message = <<~MSG
+      Translation missing. Options considered were:
+      - de-DE.missing_bar
+      - de-DE.missing_baz
+    MSG
+
+    assert_equal translation_missing_message.chomp, I18n.t(:missing_bar, :locale => :'de-DE', :default => [:missing_baz])
+  end
+
+  test "returns the simple Translation missing: message when default is an empty Array" do
+    assert_equal "Translation missing: de-DE.missing_bar", I18n.t(:missing_bar, :locale => :'de-DE', :default => [])
   end
 
   test "returns the :'de-DE' default :baz translation for a missing :'de-DE' when defaults contains Symbol" do
@@ -192,7 +202,7 @@ class I18nBackendFallbacksLocalizeTestWithMultipleThreads < I18n::TestCase
 end
 
 # See Issue #590
-class I18nBackendFallbacksSymbolReolveRestartsLookupAtOriginalLocale < I18n::TestCase
+class I18nBackendFallbacksSymbolResolveRestartsLookupAtOriginalLocale < I18n::TestCase
   class Backend < I18n::Backend::Simple
     include I18n::Backend::Fallbacks
   end
