@@ -140,6 +140,10 @@ class I18nTest < I18n::TestCase
     assert_equal [:en, :foo, :bar, :baz, :buz], I18n.normalize_keys(:en, :'baz|buz', :'foo|bar', '|')
   end
 
+  test "normalize_keys normalizes given locale with separator" do
+    assert_equal [:en, :foo, :bar, :baz], I18n.normalize_keys(:"en.foo", :baz, :bar)
+  end
+
   test "can set the exception_handler" do
     begin
       previous_exception_handler = I18n.exception_handler
@@ -205,11 +209,18 @@ class I18nTest < I18n::TestCase
   end
 
   # def test_translate_given_no_args_raises_missing_translation_data
-  #   assert_equal "translation missing: en, no key", I18n.t
+  #   assert_equal "Translation missing: en, no key", I18n.t
   # end
 
   test "translate given a bogus key returns an error message" do
-    assert_equal "translation missing: en.bogus", I18n.t(:bogus)
+    assert_equal "Translation missing: en.bogus", I18n.t(:bogus)
+  end
+
+  test "translate given multiple bogus keys returns an array of error messages" do
+    assert_equal(
+      ["Translation missing: en.bogus", "Translation missing: en.also_bogus"],
+      I18n.t([:bogus, :also_bogus]),
+    )
   end
 
   test "translate given an empty string as a key raises an I18n::ArgumentError" do
@@ -255,7 +266,7 @@ class I18nTest < I18n::TestCase
         I18n.t('foo')
       end
 
-      assert_equal 'translation missing: en.foo', I18n.t('foo', locale: :en)
+      assert_equal 'Translation missing: en.foo', I18n.t('foo', locale: :en)
     end
   end
 
@@ -296,6 +307,10 @@ class I18nTest < I18n::TestCase
     assert_equal true, I18n.exists?(:currency, :nl)
   end
 
+  test "exists? given an existing key and a scope will return true" do
+    assert_equal true, I18n.exists?(:delimiter, scope: [:currency, :format])
+  end
+
   test "exists? given a non-existing key and an existing locale will return false" do
     assert_equal false, I18n.exists?(:bogus, :nl)
   end
@@ -379,7 +394,7 @@ class I18nTest < I18n::TestCase
     assert_equal I18n.default_locale, I18n.locale
   end
 
-  test "I18n.translitarate handles I18n::ArgumentError exception" do
+  test "I18n.transliterate handles I18n::ArgumentError exception" do
     I18n::Backend::Transliterator.stubs(:get).raises(I18n::ArgumentError)
     I18n.exception_handler.expects(:call).raises(I18n::ArgumentError)
     assert_raises(I18n::ArgumentError) {
@@ -387,7 +402,7 @@ class I18nTest < I18n::TestCase
     }
   end
 
-  test "I18n.translitarate raises I18n::ArgumentError exception" do
+  test "I18n.transliterate raises I18n::ArgumentError exception" do
     I18n::Backend::Transliterator.stubs(:get).raises(I18n::ArgumentError)
     I18n.exception_handler.expects(:call).never
     assert_raises(I18n::ArgumentError) {
@@ -490,18 +505,14 @@ class I18nTest < I18n::TestCase
 
   test "can reserve a key" do
     begin
-      reserved_keys_were = I18n::RESERVED_KEYS.dup
+      stub_const(I18n, :RESERVED_KEYS, []) do
+        I18n.reserve_key(:foo)
+        I18n.reserve_key("bar")
 
-      assert !I18n::RESERVED_KEYS.include?(:foo)
-      assert !I18n::RESERVED_KEYS.include?(:bar)
-
-      I18n.reserve_key(:foo)
-      I18n.reserve_key("bar")
-
-      assert I18n::RESERVED_KEYS.include?(:foo)
-      assert I18n::RESERVED_KEYS.include?(:bar)
+        assert I18n::RESERVED_KEYS.include?(:foo)
+        assert I18n::RESERVED_KEYS.include?(:bar)
+      end
     ensure
-      I18n::RESERVED_KEYS = reserved_keys_were
       I18n.instance_variable_set(:@reserved_keys_pattern, nil)
     end
   end
